import XPILib
import sys
import os


#########################
# Start Main program    #
#########################
if __name__ == "__main__":
    timer = XPILib.Timer()
    timer.start_timer('Reading Config & Transition', is_print=False)
    # Check commandline arguments
    if len(sys.argv) != 2:
        XPILib.UserMessageXPIQuant("Config file is missing")
    # print the program information
    print(XPILib.pgm_info)

    # Read Configuration file
    config_file = sys.argv[1]
    config_obj = XPILib.XPIQuantConfig(config_file)

    # Parse Inclusion list and write Transition file
    if config_obj.data[XPILib.colname_skip_inclusion]:
        print("Skip parsing Inclusion list", end='')
        if not os.path.exists(XPILib.file_transition):
            print(", but couldn't find {0}.".format(XPILib.file_transition))
            inclusion_list = XPILib.InclusionList(config_obj)
            print("Transition file is successfully generated")
        else:
            print("\n", end='')
    else:
        inclusion_list = XPILib.InclusionList(config_obj)
        print("Transition file is successfully generated")

    # Read transition file, get target transition information and calculate mass of labeled ions (heavy ion)
    data_directory = config_obj.data[XPILib.colname_data_directory]
    transition_file = os.path.join(data_directory, XPILib.file_transition)
    labeling_obj = config_obj.labeling
    transition_obj = XPILib.Transition(transition_file, labeling_obj)
    transition_obj.get_mz_fragments()

    timer.stop_timer()

    # Extract peak information from MS Runs
    timer.start_timer('Reading PRM Runs', is_print=False)
    whole_PRM_scans = XPILib.PRMDataset(data_directory, config_obj, transition_obj)
    timer.stop_timer()
    timer.print_elapsed()

    # Filter out scans by ms windows
    timer.start_timer("Finding target PRM ions", is_print=False)
    PRMTargets_obj = XPILib.PRMTargets(transition_obj, whole_PRM_scans, config_obj)
    timer.stop_timer()
    timer.print_elapsed()

    timer.start_timer("Writing all the detected PRM Ions")
    PRMTargets_obj.print_whole_data(os.path.join(data_directory, XPILib.file_all))
    timer.stop_timer()
    timer.print_elapsed()

    fp_time = open(os.path.join(data_directory, XPILib.file_time), "w")
    fp_time.write("{0}\t{1}\n".format(XPILib.colname_data_directory, config_file))
    fp_time.write(timer.get_times())
    fp_time.close()

    print("XPI output files were generated in {0}".format(data_directory))
